emacs-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: Missing changes in merges from emacs-25 to master


From: martin rudalics
Subject: Re: Missing changes in merges from emacs-25 to master
Date: Sun, 20 Mar 2016 19:38:17 +0100

> How did you conclude that these commits are the culprit?

Running

git diff 
fbce4757a874cc43806eb41b8637538b101c3c69..82b089783e71b2aeef950eaecfe4cbc0735e64a2
 src/window.c

gets me

diff --git a/src/window.c b/src/window.c
index 8953d3c..add2de3 100644
--- a/src/window.c
+++ b/src/window.c
@@ -35,13 +35,15 @@
 #include "dispextern.h"
 #include "blockinput.h"
 #include "termhooks.h"               /* For FRAME_TERMINAL.  */
-#include "xwidget.h"
 #ifdef HAVE_WINDOW_SYSTEM
 #include TERM_HEADER
 #endif /* HAVE_WINDOW_SYSTEM */
 #ifdef MSDOS
 #include "msdos.h"
 #endif
+#ifdef HAVE_XWIDGETS
+# include "xwidget.h"
+#endif

 static ptrdiff_t count_windows (struct window *);
 static ptrdiff_t get_leaf_windows (struct window *, struct window **,
@@ -3971,11 +3973,9 @@ depends on the value of (window-start WINDOW), so if 
calling this
 }


-/* Resize frame F's windows when F's width or height is set to SIZE.
-   If HORFLAG is zero, F's width was set to SIZE, otherwise its height
-   was set.  SIZE is interpreted in F's canonical character units
-   (a.k.a. "columns" or "lines"), unless PIXELWISE is non-zero, which
-   means to interpret SIZE in pixel units.  */
+/* Resize frame F's windows when number of lines of F is set to SIZE.
+   HORFLAG means resize windows when number of columns of F is set to
+   SIZE.  PIXELWISE means to interpret SIZE as pixels.  */
 void
 resize_frame_windows (struct frame *f, int size, bool horflag, bool pixelwise)
 {
@@ -4076,7 +4076,7 @@ depends on the value of (window-start WINDOW), so if 
calling this
       m = XWINDOW (mini);
       if (horflag)
        {
-         m->total_cols = new_size;
+         m->total_cols = size;
          m->pixel_width = new_pixel_size;
        }
       else
@@ -4371,7 +4371,9 @@ SIDE t (or `right') specifies that the new window shall 
be located on

       /* Block input.  */
       block_input ();
+#ifdef HAVE_XWIDGETS
       xwidget_view_delete_all_in_window (w);
+#endif
       window_resize_apply (p, horflag);
       /* If this window is referred to by the dpyinfo's mouse
         highlight, invalidate that slot to be safe (Bug#9904).  */
@@ -7263,7 +7265,7 @@ Value is a list of the form (WIDTH COLUMNS VERTICAL-TYPE 
HEIGHT LINES

 If this variable is t, splitting a window tries to get the space
 proportionally from all windows in the same combination.  This also
-allows splitting a window that is otherwise too small or of fixed size.
+allows to split a window that is otherwise too small or of fixed size.
 Resizing and deleting a window proportionally resize all windows in the
 same combination.


What do you get?

martin



reply via email to

[Prev in Thread] Current Thread [Next in Thread]